@@ -605,6 +605,49 @@ testCompoundStruct (test_TestFactory   factory,
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 }
 
+static void
+testAlignHoleStruct (test_TestFactory   factory, 
+		    CORBA_Environment *ev)
+{
+  test_StructServer objref;
+  test_AlignHoleStruct inArg, inoutArg, outArg, retn;
+  d_print ("Testing structs with aligning holes...\n");
+  objref = test_TestFactory_getStructServer (factory, ev);
+  g_assert (ev->_major == CORBA_NO_EXCEPTION);
+
+  inArg.a.a = constants_DOUBLE_IN;
+  inArg.a.b = constants_OCTET_IN;
+  inArg.b = constants_CHAR_IN;
+
+  inoutArg.a.a = constants_DOUBLE_INOUT_IN;
+  inoutArg.a.b = constants_OCTET_INOUT_IN;
+  inoutArg.b = constants_CHAR_INOUT_IN;
+  
+  memset(&outArg, 0, sizeof(outArg));
+
+  retn = test_StructServer_opAlignHole (objref, &inArg, &inoutArg, &outArg, ev);
+  g_assert (ev->_major == CORBA_NO_EXCEPTION);
+  
+  g_assert (inArg.a.a == constants_DOUBLE_IN);
+  g_assert (inArg.a.b == constants_OCTET_IN);
+  g_assert (inArg.b == constants_CHAR_IN);
+
+  g_assert (inoutArg.a.a == constants_DOUBLE_INOUT_OUT);
+  g_assert (inoutArg.a.b == constants_OCTET_INOUT_OUT);
+  g_assert (inoutArg.b == constants_CHAR_INOUT_OUT);
+
+  g_assert (outArg.a.a == constants_DOUBLE_OUT);
+  g_assert (outArg.a.b == constants_OCTET_OUT);
+  g_assert (outArg.b == constants_CHAR_OUT);
+
+  g_assert (retn.a.a == constants_DOUBLE_RETN);	
+  g_assert (retn.a.b == constants_OCTET_RETN);	
+  g_assert (retn.b == constants_CHAR_RETN);	
+  
+  CORBA_Object_release (objref, ev);
+  g_assert (ev->_major == CORBA_NO_EXCEPTION);
+}
+
 static void
 testObjectStruct (test_TestFactory   factory, 
 		  CORBA_Environment *ev)
@@ -701,10 +744,31 @@ testUnboundedSequence (test_TestFactory   factory,
   CORBA_free (inoutArg._buffer);
   CORBA_free (outArg);
   CORBA_free (retn);
+
   CORBA_Object_release (objref, ev);
   g_assert (ev->_major == CORBA_NO_EXCEPTION);
 }
 
+static void
+testAnySequence (test_TestFactory   factory, 
+                 CORBA_Environment *ev)
+{
+    test_AnySeq *any_retn, *copy;
+    test_SequenceServer objref;
+
+    d_print ("Testing sequence<any>...\n");
+    objref = test_TestFactory_getSequenceServer (factory, ev);
+    g_assert (ev->_major == CORBA_NO_EXCEPTION);
+    
+    any_retn = test_SequenceServer_opAnySeq (objref, ev);
+    g_assert (ev->_major == CORBA_NO_EXCEPTION);
+    copy = ORBit_copy_value (any_retn, TC_test_AnySeq);
+    CORBA_free (any_retn);
+
+    CORBA_Object_release (objref, ev);
+    g_assert (ev->_major == CORBA_NO_EXCEPTION);
+}
+
 static void
 testBoundedSequence (test_TestFactory   factory, 
 		     CORBA_Environment *ev)
@@ -2203,10 +2267,12 @@ run_tests (test_TestFactory   factory,
 		testFixedLengthStruct (factory, ev);
 		testVariableLengthStruct (factory, ev);
 		testCompoundStruct (factory, ev);
+		testAlignHoleStruct (factory, ev);
 		testObjectStruct (factory, ev);
 		testStructAny (factory, ev);
 		testUnboundedSequence (factory, ev);
 		testBoundedSequence (factory, ev);
+		testAnySequence (factory, ev);
 		testFixedLengthUnion (factory, ev);
 		testVariableLengthUnion (factory, ev);
 		testMiscUnions (factory, ev);
@@ -2321,7 +2387,7 @@ main (int argc, char *argv [])
 	test_TestFactory   factory;
 	ORBit_IInterfaces *interfaces = NULL;
 	gboolean           gen_imodule = FALSE;
-	const char        *orb_name;
+	char              *orb_name;
 	int                i;
 
 	CORBA_exception_init (ev);
